@@ -2,10 +2,11 @@ use YAML;
 use Rubric::Link;
 use Rubric::User;
 
+my $rjbs = Rubric::User->retrieve(shift @ARGV || $ENV{USER});
+
 my $yaml;
 { local $/; $yaml = <>; }
 my $links = YAML::Load($yaml);
-my $rjbs = Rubric::User->retrieve($ARGV[0] || $ENV{USER});
 
 foreach (@$links) {
 	my $link = Rubric::Link->find_or_create({uri => $_->{href}});
@@ -13,8 +14,8 @@ foreach (@$links) {
 		link  => $link,
 		title => $_->{description},
 		description => $_->{extended},
-		created  => $_->{datetime},
-		modified => $_->{datetime},
+		created  => $_->{created} || $_->{datetime},
+		modified => $_->{modified} || $_->{datetime},
 	});
 	$entry->add_to_tags({tag => $_}) for @{$_->{tags}};
 }
